@@ -5,6 +5,7 @@ import os
 import signal
 import locale
 import errno
+import codecs
 
 class ClosingException(Exception):
     pass
@@ -92,23 +93,25 @@ def downloadFunc(trailerURL, command, taskDict):
 
     # now we start counting dots :-)
     downloaded = 0
+    Reader = codecs.getreader("utf-8")
+    stdReader = Reader(p.stderr)
     while True:
-        x = p.stderr.read(1).decode()
+        x = stdReader.read(1)
 
         if len(x) == 0:
             break
         if x == '.' or x ==',':
             downloaded = downloaded + 64 * 1024
-        perc = int(downloaded * 100 / totalsize)
+        perc = downloaded * 100 // totalsize
         if perc % 5 == 0:
             try:
                 taskDict[trailerURL] = DownloadStatus(trailerURL,
                            DownloadStatus.IN_PROGRESS,
                            perc)
             except IOError as e:
-                print("Ignoring interrupted assignement exception")
                 if e.errno is not errno.EINTR:
                     raise
+                print("Ignoring interrupted assignement exception")
 
     p.wait()
     if p.returncode is not 0:
