@@ -2,14 +2,14 @@
 
 # Resource object code
 #
-# Created: Wed Nov 10 00:39:52 2010
+# Created: Wed Nov 10 20:52:35 2010
 #      by: The Resource Compiler for PyQt (Qt v4.6.3)
 #
 # WARNING! All changes made in this file will be lost!
 
 from PyQt4 import QtCore
 
-qt_resource_data = b"\
+qt_resource_data = "\
 \x00\x00\x1d\x9b\
 \x47\
 \x49\x46\x38\x39\x61\xa0\x00\x18\x00\x80\x00\x00\x04\x02\x04\xfc\
@@ -488,7 +488,7 @@ qt_resource_data = b"\
 \x3c\x88\x30\xa1\xc2\x84\x05\x00\x00\x3b\
 "
 
-qt_resource_name = b"\
+qt_resource_name = "\
 \x00\x09\
 \x00\x38\x80\xfe\
 \x00\x61\
@@ -499,7 +499,7 @@ qt_resource_name = b"\
 \x00\x6f\x00\x61\x00\x64\x00\x69\x00\x6e\x00\x67\
 "
 
-qt_resource_struct = b"\
+qt_resource_struct = "\
 \x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
 \x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x02\
 \x00\x00\x00\x18\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
